@@ -13,7 +13,6 @@ library("openxlsx")
 library("readxl")
 library("stringr")
 library("readr")
-library("magick")
 library("DT")
 library("gplots")
 library("RODBC")
@@ -28,7 +27,7 @@ shinyUI(dashboardPage(skin = "black",
                       # Tricky way of placing elements in dashboardHeader, expects a tag element of type li and class dropdown, 
                       # so we can pass such elements instead of dropdownMenus
                       dashboardHeader(title = "MEM dashboard",
-                                      tags$li("06JUN2017, code under GPLv2 at",
+                                      tags$li("memapp v2.1.20170608, code under GPLv2 at",
                                               class = "dropdown"),
                                       tags$li(a(href = 'https://github.com/lozalojo/memapp',
                                                 img(src = 'GitHub_Logo.png',
@@ -126,6 +125,26 @@ shinyUI(dashboardPage(skin = "black",
                         fluidPage(
                           # Application title
                           titlePanel(h1("The Moving Epidemics Method Shiny Web Application")),
+                          tagList(
+                            singleton(tags$head(
+                              tags$link(rel="stylesheet", type="text/css",href="busyIndicator.css")
+                            ))
+                            ,div(class="shinysky-busy-indicator",p("Calculation in progress. This may take a while..."),img(src="ajaxloaderq.gif"))
+                            ,tags$script(sprintf(
+                              "	setInterval(function(){
+                              if ($('html').hasClass('shiny-busy')) {
+                              setTimeout(function() {
+                              if ($('html').hasClass('shiny-busy')) {
+                              $('div.shinysky-busy-indicator').show()
+                              }
+                              }, %d)  		    
+                              } else {
+                              $('div.shinysky-busy-indicator').hide()
+                              }
+                              },100)
+                              ",500)
+                            )
+                          ),
                           fluidRow(
                             ###################################
                             ### BODY/MAIN SECTION           ###
@@ -139,94 +158,10 @@ shinyUI(dashboardPage(skin = "black",
                                    #######################################
                                    tabBox(
                                      title = "MEM", width = 12, height = "800px",
-                                     tabPanel("Check & describe", 
-                                              tagList(
-                                                singleton(tags$head(
-                                                  tags$link(rel="stylesheet", type="text/css",href="busyIndicator.css")
-                                                ))
-                                                ,div(class="shinysky-busy-indicator",p("Calculation in progress. This may take a while..."),img(src="ajaxloaderq.gif"))
-                                                ,tags$script(sprintf(
-                                                  "	setInterval(function(){
-                                                  if ($('html').hasClass('shiny-busy')) {
-                                                  setTimeout(function() {
-                                                  if ($('html').hasClass('shiny-busy')) {
-                                                  $('div.shinysky-busy-indicator').show()
-                                                  }
-                                                  }, %d)  		    
-                                                  } else {
-                                                  $('div.shinysky-busy-indicator').hide()
-                                                  }
-                                                  },100)
-                                                  ",500)
-                                                )
-                                              ),
-                                              "Check data series, timing and describe the data", uiOutput("tbData")),
-                                     tabPanel("Model", 
-                                              tagList(
-                                                singleton(tags$head(
-                                                  tags$link(rel="stylesheet", type="text/css",href="busyIndicator.css")
-                                                ))
-                                                ,div(class="shinysky-busy-indicator",p("Calculation in progress. This may take a while..."),img(src="ajaxloaderq.gif"))
-                                                ,tags$script(sprintf(
-                                                  "	setInterval(function(){
-                                                  if ($('html').hasClass('shiny-busy')) {
-                                                  setTimeout(function() {
-                                                  if ($('html').hasClass('shiny-busy')) {
-                                                  $('div.shinysky-busy-indicator').show()
-                                                  }
-                                                  }, %d)  		    
-                                                  } else {
-                                                  $('div.shinysky-busy-indicator').hide()
-                                                  }
-                                                  },100)
-                                                  ",500)
-                                                )
-                                              ),
-                                              "Summary, graphs, goodness and optimization of the MEM model", uiOutput("tbModel")),
-                                     tabPanel("Surveillance", 
-                                              tagList(
-                                                singleton(tags$head(
-                                                  tags$link(rel="stylesheet", type="text/css",href="busyIndicator.css")
-                                                ))
-                                                ,div(class="shinysky-busy-indicator",p("Calculation in progress. This may take a while..."),img(src="ajaxloaderq.gif"))
-                                                ,tags$script(sprintf(
-                                                  "	setInterval(function(){
-                                                  if ($('html').hasClass('shiny-busy')) {
-                                                  setTimeout(function() {
-                                                  if ($('html').hasClass('shiny-busy')) {
-                                                  $('div.shinysky-busy-indicator').show()
-                                                  }
-                                                  }, %d)  		    
-                                                  } else {
-                                                  $('div.shinysky-busy-indicator').hide()
-                                                  }
-                                                  },100)
-                                                  ",500)
-                                                )
-                                              ),
-                                              "Surveillance tools", uiOutput("tbSurveillance")),
-                                     tabPanel("Visualize", 
-                                              tagList(
-                                                singleton(tags$head(
-                                                  tags$link(rel="stylesheet", type="text/css",href="busyIndicator.css")
-                                                ))
-                                                ,div(class="shinysky-busy-indicator",p("Calculation in progress. This may take a while..."),img(src="ajaxloaderq.gif"))
-                                                ,tags$script(sprintf(
-                                                  "	setInterval(function(){
-                                                  if ($('html').hasClass('shiny-busy')) {
-                                                  setTimeout(function() {
-                                                  if ($('html').hasClass('shiny-busy')) {
-                                                  $('div.shinysky-busy-indicator').show()
-                                                  }
-                                                  }, %d)  		    
-                                                  } else {
-                                                  $('div.shinysky-busy-indicator').hide()
-                                                  }
-                                                  },100)
-                                                  ",500)
-                                                )
-                                              ),
-                                              "Visualize different sets of data with a MEM model", uiOutput("tbVisualize"))
+                                     tabPanel("Check & describe", "Check data series, timing and describe the data", uiOutput("tbData")),
+                                     tabPanel("Model", "Summary, graphs, goodness and optimization of the MEM model", uiOutput("tbModel")),
+                                     tabPanel("Surveillance", "Surveillance tools", uiOutput("tbSurveillance")),
+                                     tabPanel("Visualize", "Visualize different sets of data with a MEM model", uiOutput("tbVisualize"))
                                    )
                             ),
                             ###################################
